/*
 *  smpeg-xmms - (S)MPEG Plugin for XMMS
 *  Copyright (C) 2000-2001 4Front Technologies
 *  http://www.opensound.com
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */ 

#ifndef SMPEG_XMMS_H

extern void smpeg_configure(void);
extern void smpeg_read_config(void);

typedef struct
{
	gboolean double_mode;
	gboolean fullscreen_mode;
	gboolean center_mode;
	gboolean states_mode;
	gboolean windowsize_mode;
	gboolean ratio_mode;
	gboolean wratio_mode;
	gboolean window_mode;
	gboolean filter_mode;
	gboolean xmmsaudio_mode;
	gboolean audioonly_mode;
	gboolean samevideo_mode;
	gint sizew_mode, sizeh_mode;
}
SmpegConfig;

extern SmpegConfig smpeg_cfg;

#endif
